//
//  WebViewController.swift
//  SpeechSample
//
//  Created by MasaKentaro on 2016/08/07.
//  Copyright © 2016年 MasaKentaro. All rights reserved.
//

import UIKit
import AVFoundation

class WebViewController: UIViewController, UIWebViewDelegate {

    var rate: Float = AVSpeechUtteranceDefaultSpeechRate
    var pitchMultiplier: Float = 1.0
    var volume: Float = 1.0
    var preUtteranceDelay: TimeInterval = 0
    var urlText: String = ""
    
    var synthesizer: AVSpeechSynthesizer!
    
    @IBOutlet weak var webView: UIWebView!
    @IBOutlet weak var activityIndicator: UIActivityIndicatorView!
    
    override func viewDidLoad() {
        super.viewDidLoad()

        // Do any additional setup after loading the view.
        webView.delegate = self;
        
        if let url = URL(string: urlText) {
            let urlRequest = URLRequest(url: url)
            webView.loadRequest(urlRequest)
        }
        
        synthesizer = AVSpeechSynthesizer()
    }

    override func didReceiveMemoryWarning() {
        super.didReceiveMemoryWarning()
        // Dispose of any resources that can be recreated.
    }
    

    /*
    // MARK: - Navigation

    // In a storyboard-based application, you will often want to do a little preparation before navigation
    override func prepare(for segue: UIStoryboardSegue, sender: AnyObject?) {
        // Get the new view controller using segue.destinationViewController.
        // Pass the selected object to the new view controller.
    }
    */
    
    func webViewDidStartLoad(_ webView: UIWebView) {
        UIApplication.shared.isNetworkActivityIndicatorVisible = true
        activityIndicator.startAnimating()
    }
    
    func webViewDidFinishLoad(_ webView: UIWebView) {
        UIApplication.shared.isNetworkActivityIndicatorVisible = false
        activityIndicator.stopAnimating()
        navigationItem.title =
            webView.stringByEvaluatingJavaScript(from: "document.title")
    }

    @IBAction func playButtonTapped(sender: UIBarButtonItem) {
        
        if synthesizer.isPaused {
            synthesizer.continueSpeaking()
        } else {
            guard let webText = webView.stringByEvaluatingJavaScript(from:
                    "document.body.innerText") else {
                return
            }
            
            print (webText)
            
            let utterance = AVSpeechUtterance(string: webText)
            
            utterance.rate = rate
            utterance.pitchMultiplier = pitchMultiplier
            utterance.volume = volume
            utterance.preUtteranceDelay = preUtteranceDelay
            utterance.voice = AVSpeechSynthesisVoice(language: "ja-JP")
            
            print(String(describing: utterance.voice))
            
            synthesizer.speak(utterance)
        }
        
    }
    
    @IBAction func pauseButtonTapped(sender: AnyObject) {
        synthesizer.pauseSpeaking(at: .immediate)
    }
    
    override func prepare(for segue: UIStoryboardSegue, sender: Any?){
        synthesizer.stopSpeaking(at: .immediate)
    }

}
